﻿using System;
using System.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace Chess.Test
{
    [TestClass]
    public class PawnTest
    {
        private Pawn Target { get; set; }

        [TestInitialize]
        public void BeforeEachTest()
        {
            Target = new Pawn();
        }

        [TestClass]
        public class GetMovesFrom : PawnTest
        {
            [TestMethod]
            public void Returns4_3AsOneResultWhenPassed4_2()
            {
                var bc = new BoardCoordinate(4, 2);
                var possibleMoves = Target.GetMovesFrom(bc, 8);

                Assert.IsTrue(possibleMoves.Any(c => c.Equals(new BoardCoordinate(4,3))));
            }

            [TestMethod]
            public void Returns4_4AsOneResultWhenPassed4_2WhenPieceHasNotMoved()
            {
                var bc = new BoardCoordinate(4, 2);
                var possibleMoves = Target.GetMovesFrom(bc, 8);

                Assert.IsTrue(possibleMoves.Any(c => c.Equals(new BoardCoordinate(4, 4))));
            }

            [TestMethod]
            public void DoesNotReturn4_4AsOneResultWhenPassed4_2IfPieceHasAlreadyMoved()
            {
                Target.HasMoved = true;
                var bc = new BoardCoordinate(4, 2);
                var possibleMoves = Target.GetMovesFrom(bc, 8);

                Assert.IsFalse(possibleMoves.Any(c => c.Equals(new BoardCoordinate(4, 4))));
            }
        }

    }
}
